@@ -3,6 +3,7 @@ import sys
 import time
 import subprocess
 import pathlib
+from tkinter.tix import Tree
 from semver import VersionInfo
 from cement import Controller, ex
 from ..core.config import load_config
@@ -178,7 +179,15 @@ class Crawler(Controller):
     def deploy(self):
 
         toolbar_width = 50
+        verbose_mode = False
 
+        try:
+            if self.config.deploy.verbose == True:
+                verbose_mode = True
+        except:
+            verbose_mode = False
+
+        verbose_mode = self.app.pargs.verbose
         input_plugin_name = self.app.pargs.plugin_name
         deploy_message = self.app.pargs.message
 
@@ -248,7 +257,7 @@ class Crawler(Controller):
                     self.app.log.info(
                         "[{}] [{}] {}".format(deploy_type, version_info, deploy_message))
 
-                if self.app.pargs.verbose is False:
+                if verbose_mode is False:
                     sys.stdout.write(
                         "Deploying: [%s]" % (" " * toolbar_width))
                     sys.stdout.flush()
@@ -270,7 +279,7 @@ class Crawler(Controller):
                         git push origin master --quiet
                         """
 
-                    if self.app.pargs.verbose is True:
+                    if verbose_mode is True:
                         cmd = f"""
                         cd {plugin_dir_path} &&
                         cd .. &&
@@ -281,14 +290,14 @@ class Crawler(Controller):
                         git commit -m "[{deploy_type}] [{version_info}] {deploy_message}" &&
                         git push origin master
                         """
-                    if self.app.pargs.verbose is False:
+                    if verbose_mode is False:
                         progress = int(.40 * toolbar_width)
                         sys.stdout.write("-" * progress)
                         sys.stdout.flush()
 
                     subprocess.run(
                         cmd, shell=True, check=True)
-                    if self.app.pargs.verbose is False:
+                    if verbose_mode is False:
                         progress = int(.30 * toolbar_width)
                         sys.stdout.write("-" * progress)
                         sys.stdout.flush()
@@ -299,7 +308,7 @@ class Crawler(Controller):
                         f'There was a problem deploying {plugin_name}')
                     return
 
-                if self.app.pargs.verbose is False:
+                if verbose_mode is False:
                     progress = int(.20 * toolbar_width)
                     sys.stdout.write("-" * progress)
                     sys.stdout.flush()
