@@ -130,7 +130,7 @@ def save_config(update=False):
     with open(config_path + '/config.yml', 'w') as w:
         w.write(yaml.dump(setup_config))
 
-    _generate_autocomplete_script(crawler_paths)
+    generate_autocomplete_script(crawler_paths)
 
 
 def _yes_no_prompt(ques):
@@ -141,8 +141,8 @@ def _yes_no_prompt(ques):
         return False
 
 
-def _generate_autocomplete_script(crawler_paths):
-    Log.info("Generating Autocomplete Script")
+def generate_autocomplete_script(crawler_paths):
+    
     data = {}
     data['paths'] = []
     for p in range(len(crawler_paths)):
@@ -168,21 +168,17 @@ def _generate_autocomplete_script(crawler_paths):
 
         with open(config_path + f'/{auto_script}.sh', 'w') as dest_file:
             dest_file.write(template.render(data))
-
+    Log.info(f"Generating Autocomplete Script for {platform.system()}")
     if(platform.system() == 'Linux'):
-        # check if autocomplete has already been sourced in .bashrc file
+        
         with open(path.expanduser('~/.bashrc')) as rc_file:
             rc_file = rc_file.read()
-            if("source $HOME/.grepsr/autocomplete.sh" in rc_file):
-                print("Already added !!")
-            else:
+            if(".grepsr/autocomplete.sh" not in rc_file):
                 system(
                     '''echo "source $HOME/.grepsr/autocomplete.sh" >>  ~/.bashrc''')
     elif (platform.system() == 'Darwin'):
         with open(path.expanduser(path.expanduser('~/.zshrc'))) as rc_file:
             rc_file = rc_file.read()
-            if("source $HOME/.grepsr/autocomplete_zsh.sh" in rc_file):
-                print("Already added !!")
-            else:
+            if(".grepsr/autocomplete_zsh.sh" not in rc_file):
                 system(
                     '''echo "source $HOME/.grepsr/autocomplete_zsh.sh" >>  ~/.zshrc''')
